=============
skystatistics
=============

The ``skystatistics`` module contains various statistical
functions used by ``skymatch.``

.. currentmodule:: romancal.skymatch.skystatistics

.. automodule:: romancal.skymatch.skystatistics
   :members:
   :undoc-members:
